﻿using System.Threading.Tasks;
using Xunit;
using MySql.Data.MySqlClient;

namespace ProxySqlBug
{
    public class ProxySqlBugTests
    {
        private const string databaseName = "bug-db";
        private const string connectionString = "uid=root;pwd=password;server=localhost;Connect Timeout=30;CharSet='utf8mb4';Treat Tiny As Boolean=True;CheckParameters=false;Allow User Variables=True;SslMode=Required;";
        private const string mySqlPort = "3306";
        private const string proxySqlPort = "6033";

        public ProxySqlBugTests()
        {
            using var connection = new MySqlConnection($"{connectionString}Port={mySqlPort}");
            connection.Open();

            var cmd = new MySqlCommand($"DROP DATABASE IF EXISTS `{databaseName}`;", connection);
            cmd.ExecuteNonQuery();
            cmd = new MySqlCommand($"CREATE SCHEMA IF NOT EXISTS `{databaseName}`;", connection);
            cmd.ExecuteNonQuery();

            using var dbConn = new MySqlConnection($"{connectionString}Port={mySqlPort};database ={databaseName};");
            dbConn.Open();
            cmd = new MySqlCommand(@"CREATE TABLE `auditlog` (
                    `AuditLogId` bigint(11) NOT NULL AUTO_INCREMENT,
                    `AuditDate` datetime(6) NOT NULL,
                    `Notes` text NOT NULL,
                    `HostName` varchar(200) DEFAULT NULL,
                    `LastModified` datetime(6) DEFAULT NULL,
                    `AuditActionId` bigint(11) NOT NULL,
                    `CreatedDate` datetime(6) DEFAULT NULL,
                    `CreatedBy` bigint(11) DEFAULT NULL,
                    `AuditArea` varchar(200) DEFAULT NULL,
                PRIMARY KEY (`AuditLogId`)) ENGINE=InnoDB;", dbConn);
            cmd.ExecuteNonQuery();
        }


        [Fact]
        public async Task InsertViaMySql_ExpectPass()
        {
            await Audit.InsertAudits($"{connectionString}Port={mySqlPort};database ={databaseName};");
        }

        [Fact]
        public async Task InsertViaProxySql_ExpectPass()
        {
            await Audit.InsertAudits($"{connectionString}Port={proxySqlPort};database ={databaseName};");
        }
    }
}